Miscellaneous tools
===================

In this section, we give an overview of various tools and patterns that can be useful for quick data analysis.
The aim of these tools is not to reinvent standard Python functionality or imitate extensive third-party plotting and data libraries.
In stead, we use a minimalistic approach to achieve quick (and often dirty) results.
It's main purpouse is to bundle repeating initialization patterns and parameters into reusable units, and thus preserve simplicity and improve readability of scripts.
Any more insights, and suggestion for best practices are welcomed.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cached_function
   data_combination
   data_plot_grid
   normalize_data
   parameter_table
   progress_bar
   row_collector
   stopwatch
   thumbnail_image
   image_metadata